@@ -63,6 +63,7 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 	m_settings.add(m_config_form.ui_chkAutoSaveOnExit);
 	m_settings.add(m_config_form.ui_chkShowA4Offset);
 
+	m_settings.add(m_config_form.ui_cbTuning);
 	m_settings.add(m_config_form.ui_cbTonality);
 	m_settings.add(m_config_form.ui_cbNotesName);
 	m_settings.add(ui_spinAFreq);
@@ -213,6 +214,7 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 	connect(m_config_form.ui_btnRestoreFactorySettings, SIGNAL(clicked()), this, SLOT(restoreFactorySettings()));
 	connect(m_config_form.ui_spinMinHT, SIGNAL(valueChanged(int)), this, SLOT(noteRangeChanged()));
 	connect(m_config_form.ui_spinMaxHT, SIGNAL(valueChanged(int)), this, SLOT(noteRangeChanged()));
+	connect(m_config_form.ui_cbTuning, SIGNAL(highlighted(int)), this, SLOT(noteRangeChanged()));
 	connect(m_config_form.ui_cbTonality, SIGNAL(highlighted(int)), this, SLOT(noteRangeChanged()));
 	connect(m_config_form.ui_cbNotesName, SIGNAL(highlighted(int)), this, SLOT(noteRangeChanged()));
 	connect(m_config_form.ui_btnAutoDetect, SIGNAL(clicked()), this, SLOT(autoDetectTransport()));
@@ -695,6 +697,28 @@ void CustomInstrumentTunerForm::configure()
 }
 void CustomInstrumentTunerForm::configure_ok()
 {
+	switch(m_config_form.ui_cbTuning->currentItem())
+	{
+	case 0:
+		SetTuning(CHROMATIC);
+		break;
+	case 1:
+		SetTuning(WERCKMEISTER3);
+		break;
+	case 2:
+		SetTuning(KIRNBERGER3);
+		break;
+	case 3:
+		SetTuning(DIATONIC);
+		break;
+	case 4:
+		SetTuning(MEANTONE);
+		break;
+	default:
+		SetTuning(CHROMATIC);
+		break;
+	}
+
 	if(m_config_form.ui_cbTonality->currentItem()==0)		SetTonality(0);
 	else if(m_config_form.ui_cbTonality->currentItem()==1)	SetTonality(+2);
 	else													SetTonality(-3);
@@ -867,7 +891,7 @@ void CustomInstrumentTunerForm::loadSettings()
 	}
 	catch(QString error)
 	{
-		cerr << "CustomInstrumentTunerForm: ERROR: " << error << endl;
+//		cerr << "CustomInstrumentTunerForm: ERROR: " << error << endl;
 	}
 	Pa_Terminate();
 #endif
