@@ -216,7 +216,7 @@ void MScale::load_scala(const QString& file_name)
 					float cents=0.0;
 					stringstream in(buff);
 					in >> cents;
-					if(cents<=0.0) throw QString("Line ")+QString::number(num_line)+": Parsed cents value is negative '"+QString::number(cents)+"'";
+					if(cents<0.0) throw QString("Line ")+QString::number(num_line)+": Parsed cents value is negative '"+QString::number(cents)+"'";
 					values.push_back(MValue(cents));
 				}
 			}
