@@ -11,11 +11,11 @@
     </message>
     <message>
         <source>Sound Capture</source>
-        <translation>Capture du son</translation>
+        <translation type="obsolete">Capture du son</translation>
     </message>
     <message>
         <source>Auto detect at startup</source>
-        <translation>Détection automatique au démarrage</translation>
+        <translation type="obsolete">Détection automatique au démarrage</translation>
     </message>
     <message>
         <source>Auto detect</source>
@@ -25,10 +25,6 @@
         <source>ALSA</source>
         <translation></translation>
     </message>
-    <message>
-        <source>PCM name</source>
-        <translation></translation>
-    </message>
     <message>
         <source>hw:0</source>
         <translation></translation>
@@ -103,7 +99,7 @@
     </message>
     <message encoding="UTF-8">
         <source> °/..</source>
-        <translation>°/..</translation>
+        <translation type="obsolete">°/..</translation>
     </message>
     <message>
         <source>volume treshold in per thousands !</source>
@@ -111,7 +107,7 @@
     </message>
     <message>
         <source>Length factor</source>
-        <translation>Facteur de longueur</translation>
+        <translation type="obsolete">Facteur de longueur</translation>
     </message>
     <message>
         <source>so much to say ...</source>
@@ -133,10 +129,6 @@
         <source>in per thousands !</source>
         <translation type="obsolete">en pourmilles !</translation>
     </message>
-    <message>
-        <source>%</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Frequency Analysis</source>
         <translation type="obsolete">Analyse de la fréquence</translation>
@@ -151,7 +143,7 @@
     </message>
     <message>
         <source>Tolerance of the error variance</source>
-        <translation>Tolérance sur la variance de l&apos;erreur</translation>
+        <translation type="obsolete">Tolérance sur la variance de l&apos;erreur</translation>
     </message>
     <message>
         <source>Views</source>
@@ -280,7 +272,7 @@ latine: Do Re Mi Fa Sol La Si</translation>
     </message>
     <message>
         <source>Use theses settings and exist configure panel (but don&apos;t save them !)</source>
-        <translation>Utiliser cette configuration (mais ne la sauvegarde pas !)</translation>
+        <translation type="obsolete">Utiliser cette configuration (mais ne la sauvegarde pas !)</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
@@ -320,7 +312,7 @@ Latine: Do Re Mi Fa Sol La Si</translation>
     </message>
     <message>
         <source>&lt;b&gt;To get more options:&lt;/b&gt; right-click every view to show up their properties !</source>
-        <translation>&lt;b&gt;Pour obtenir plus d&apos;options:&lt;/b&gt; cliquez les vues avec le boutton droit de la souris pour faire apparaître leurs propriétés !</translation>
+        <translation type="obsolete">&lt;b&gt;Pour obtenir plus d&apos;options:&lt;/b&gt; cliquez les vues avec le boutton droit de la souris pour faire apparaître leurs propriétés !</translation>
     </message>
     <message>
         <source>Volume threshold</source>
@@ -336,19 +328,19 @@ Latine: Do Re Mi Fa Sol La Si</translation>
     </message>
     <message>
         <source>Time between each sound analysis. Increase to get less CPU usage but less time resolution.</source>
-        <translation>Temps entre chaque analyse du son. Augmenter pour réduire l&apos;utilisation du processeur mais baisser la résolution temporelle.</translation>
+        <translation type="obsolete">Temps entre chaque analyse du son. Augmenter pour réduire l&apos;utilisation du processeur mais baisser la résolution temporelle.</translation>
     </message>
     <message>
         <source>Frequency analysis range.</source>
-        <translation>Portée de l&apos;analyse des fréquences.</translation>
+        <translation type="obsolete">Portée de l&apos;analyse des fréquences.</translation>
     </message>
     <message>
         <source>Minimal half-tone from A3</source>
-        <translation>Demi-ton minimum depuis La3</translation>
+        <translation type="obsolete">Demi-ton minimum depuis La3</translation>
     </message>
     <message>
         <source>Maximal half-tone form A3</source>
-        <translation>Demi-ton maximum depuis La3</translation>
+        <translation type="obsolete">Demi-ton maximum depuis La3</translation>
     </message>
     <message>
         <source>Ignore all sounds with volume below this threshold (in perthousands !)(shown has a red line in the graph view).</source>
@@ -357,51 +349,43 @@ Latine: Do Re Mi Fa Sol La Si</translation>
     </message>
     <message>
         <source>Wave-length average size</source>
-        <translation>Taille de la moyenne de la longueur d&apos;onde</translation>
+        <translation type="obsolete">Taille de la moyenne de la longueur d&apos;onde</translation>
     </message>
     <message>
         <source>Size of the average to compute the frequency in one analysis.</source>
-        <translation>Taille de la moyenne utilisée pour calculer la fréquence dans une analyse.</translation>
+        <translation type="obsolete">Taille de la moyenne utilisée pour calculer la fréquence dans une analyse.</translation>
     </message>
     <message>
         <source>Algorithms</source>
-        <translation>Algorithmes</translation>
+        <translation type="obsolete">Algorithmes</translation>
     </message>
     <message>
         <source>Default algorithm</source>
-        <translation>Algorithme par défaut</translation>
+        <translation type="obsolete">Algorithme par défaut</translation>
     </message>
     <message>
         <source>for microtonal view</source>
-        <translation>pour la vue microtonale</translation>
-    </message>
-    <message>
-        <source>Multi-Correlation</source>
-        <translation></translation>
+        <translation type="obsolete">pour la vue microtonale</translation>
     </message>
     <message>
         <source>Increase recognition quality at cost of processor usage.</source>
-        <translation>Améliore la qualité de la reconnaissance au dépend du processeur.</translation>
-    </message>
-    <message>
-        <source>Shifting test complexity</source>
-        <translation></translation>
+        <translation type="obsolete">Améliore la qualité de la reconnaissance au dépend du processeur.</translation>
     </message>
     <message>
         <source>Error noise threshold</source>
-        <translation>Seuil du bruit de l&apos;erreur</translation>
+        <translation type="obsolete">Seuil du bruit de l&apos;erreur</translation>
     </message>
     <message>
         <source>Consider as valuable all errors below this.</source>
-        <translation>Considère comme valable toutes les erreurs en-dessous de ce seuil.</translation>
+        <translation type="obsolete">Considère comme valable toutes les erreurs en-dessous de ce seuil.</translation>
     </message>
     <message>
         <source>Auto-Correlation (usualy used for Microtonal view)</source>
-        <translation>Auto-Correlation (utilisé normalement pour la vue microtonale)</translation>
+        <translation type="obsolete">Auto-Correlation (utilisé normalement pour la vue microtonale)</translation>
     </message>
     <message>
         <source>Consider as valuable all errors below this (in per thousands !)</source>
-        <translation>Considère comme valable toutes les erreurs en-dessous de ce seuil (en pour-milles !)</translation>
+        <translation type="obsolete">Considère comme valable toutes les erreurs en-dessous de ce seuil (en pour-milles !)</translation>
     </message>
     <message>
         <source>Convolution threshold</source>
@@ -419,19 +403,19 @@ Latine: Do Re Mi Fa Sol La Si</translation>
         <source>Use anglo-saxon or latin notes name.
 englo-saxon: C D E F G A B
 latin: Do Re Mi Fa Sol La </source>
-        <translation>Utiliser la notation anglo-saxone ou latine.
+        <translation type="obsolete">Utiliser la notation anglo-saxone ou latine.
 Anglo-saxon: C D E F G A B
 Latine: Do Re Mi Fa Sol La Si</translation>
     </message>
     <message>
         <source>Consider as unstable all sound with frequency variance above this (in half-tones).</source>
-        <translation>Considère comme instable tout les sons dont la variance de l&apos;erreur est au dessus de ce seuil (en demi-ton).</translation>
+        <translation type="obsolete">Considère comme instable tout les sons dont la variance de l&apos;erreur est au dessus de ce seuil (en demi-ton).</translation>
     </message>
     <message>
         <source>The tonality of the showed notes name.
 Usefull for converting notes name to a corresponding instrument tonality.
 (examples: Eb for saxophone, Bb for trumpet, etc.)</source>
-        <translation>La tonalité des noms des notes.
+        <translation type="obsolete">La tonalité des noms des notes.
 Utile pour convertir le nom des notes dans la tonalité d&apos;un instrument.
 (examples: Mib pour le saxophone, Sib pour la trompette, etc.)</translation>
     </message>
@@ -444,13 +428,13 @@ Plus petites est la valeur plus vite le program répond, mais plus la fréquence
     <message>
         <source>Ignore all sounds with volume below this threshold (in perthousands !)
 (shown has a red line in the graph view).</source>
-        <translation>Ignore tout les sons dont le volume est inférieur à ce seuil (en pour-milles !)
+        <translation type="obsolete">Ignore tout les sons dont le volume est inférieur à ce seuil (en pour-milles !)
 (visible sous la forme d&apos;une ligne rouge dans la vue du graphe).</translation>
     </message>
     <message>
         <source>Response of the program and tolerance of holes, scratches, artefacts, etc.
 Smaller is the value faster the tuner respond, but more unstable the computed frequency is.</source>
-        <translation>Temps de réponse du program et tolérance des trous, grésillements, etc.
+        <translation type="obsolete">Temps de réponse du program et tolérance des trous, grésillements, etc.
 Plus petites est la valeur plus vite le program répond, mais plus la fréquence calculée est instable.</translation>
     </message>
     <message>
@@ -463,16 +447,266 @@ Plus petites est la valeur plus vite le program répond, mais plus la fréquence
     </message>
     <message>
         <source>Show A3 offset spin box</source>
-        <translation>Montrer la boite de décalage du La3</translation>
+        <translation type="obsolete">Montrer la boite de décalage du La3</translation>
     </message>
     <message>
         <source>Detect now</source>
-        <translation>Détecter maintenant</translation>
+        <translation type="obsolete">Détecter maintenant</translation>
     </message>
     <message>
         <source>mix channels if they are multiple (will use the first channel if not checked)</source>
         <translation>mélanger les canaux s&apos;il y en a plusieurs (utilise le premier sinon)</translation>
     </message>
+    <message>
+        <source>PortAudio</source>
+        <translation>PortAudio</translation>
+    </message>
+    <message>
+        <source>Device name</source>
+        <translation>Nom du device</translation>
+    </message>
+    <message>
+        <source>default</source>
+        <translation>default</translation>
+    </message>
+    <message>
+        <source>OSS</source>
+        <translation>OSS</translation>
+    </message>
+    <message>
+        <source>/dev/dsp</source>
+        <translation>/dev/dsp</translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;To get more options:&lt;/b&gt;&lt;br&gt;
+right-click every view to show up their properties !</source>
+        <translation>&lt;b&gt;Pour plus d&apos;options:&lt;/b&gt;&lt;br&gt;
+click-droit sur les vues pour afficher leurs propriétés !</translation>
+    </message>
+    <message>
+        <source>Auto detect now</source>
+        <translation>Détecter maintenant</translation>
+    </message>
+    <message>
+        <source>Selected capture system</source>
+        <translation>Système de capture sélectionné</translation>
+    </message>
+    <message>
+        <source>Auto-detect a working one at startup</source>
+        <translation>En détecter un automatiquement au lancement</translation>
+    </message>
+    <message>
+        <source>dB</source>
+        <translation>dB</translation>
+    </message>
+    <message>
+        <source>Algorithm</source>
+        <translation>Algorithme</translation>
+    </message>
+    <message>
+        <source>Quantizer</source>
+        <translation>Quantizer</translation>
+    </message>
+    <message>
+        <source>Frequency refinement</source>
+        <translation>Raffinage de la fréquence</translation>
+    </message>
+    <message>
+        <source>Use sub-harmonic audibility treshold</source>
+        <translation>Utiliser un seuil d&apos;audibilité de sous-harmonique</translation>
+    </message>
+    <message>
+        <source>Maximum number of harmonics</source>
+        <translation>Nombre maximum d&apos;harmoniques</translation>
+    </message>
+    <message>
+        <source>Do not use a too big sampling rate. This is not so much important for pitch recognition, 22050Hz should be largely enough.</source>
+        <translation type="obsolete">Ne pas utiliser une fréquence d&apos;échantillonage trop élevée. 22050Hz devrait être largement suffisant dans la pluspart des cas.</translation>
+    </message>
+    <message>
+        <source>Range filtering</source>
+        <translation>Filtrage de la portée</translation>
+    </message>
+    <message>
+        <source>Maximum number of periods</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not use a too big sampling rate. 22050Hz should be largely enough in most cases.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rectangular filter: bad precision, but very fast</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FIR filter: good precision, but more costly in CPU usage</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Window size factor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The tonality of the notes name.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The tonality of the notes name.
+Usefull for converting notes name to a corresponding instrument tonality.
+(examples: Eb for saxophone, Bb for trumpet, etc.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use anglo-saxon or latin notes name:
+anglo-saxon: C D E F G A B
+latin: Do Re Mi Fa Sol La </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use anglo-saxon or latin notes name:
+anglo-saxon: C D E F G A B
+latin: Do Re Mi Fa Sol La</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show A4 offset spin box</source>
+        <translation type="unfinished">Montrer la boite de décalage du La4</translation>
+    </message>
+    <message>
+        <source>right-click every view to show up their properties !</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Capture System</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The selected capture system: the sound server, sound library, like:
+JACK, ALSA, OSS, PortAudio</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-detect an available capture system at startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-detect an available capture system at startup.
+Even if the capture system is available, it may not works if it&apos;s bad configured.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-detect an available capture system now.
+Even if the capture system is available, it may not works if it&apos;s bad configured.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The name of FMIT under the JACK connection system</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connect automaticaly FMIT to the following source at startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connect automaticaly FMIT to the this source at startup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sampling rate of the JACK server</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The device name, where the ALSA library have to be connected to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The sampling rate, sampling frequency, number of samples by second ...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The sampling rate, sampling frequency, number of samples by second ...
+Do not rise it too much. Around 22050Hz should be largely enough in most cases.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time between each sound analysis.
+Increase to get less CPU usage but less time precision.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Frequency analysis range: from the lowest note to the highest from the A4 reference note.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lowest semi-tone from the A4 reference note.
+Sometimes, this is usefull to put it higher than -35 to avoid a noise from the sector alimentation.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lowest semi-tone from the A4 reference note in frequency.
+Sometimes, this is usefull to put it higher than 50hz to avoid a noise from the sector alimentation.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Highest semi-tone from the A4 reference note.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Highest semi-tone from the A4 reference note in frequency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter frequencies belove the lowest semi-tone and above the highest semi-tone to avoid artefacts, noises, in all the following steps of the sound analysis.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter frequencies belove the lowest semi-tone and above the highest semi-tone
+to avoid artefacts, noises, in all the following steps of the sound analysis.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Algorithm settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignore all sounds with volume below this threshold.
+in dB in frequency domain.
+(shown has a red line in different views)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignore weak sub-harmonics.
+The treshold is defined between two neighborhood frequency components.
+Prevent too-low errors.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Factor defining the window size from the lowest period define by the range.
+Bigger is this factor, more stable is the analysis but more CPU the program will need and slower the program will react to sound changes.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Frequency domain fundamental refinement:
+Mean of the fundamental relative frequencies of the harmonics.
+Choose the number of harmonics to use.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time domain fundamental refinement:
+Mean of period lengths.
+Choose the number of period to use.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Quantize the analysis results: ignore frequency jumps, fill holes, ignore too short notes.
+Smaller is the following value, faster the tuner respond, but more unstable the computed frequency is.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use theses settings and exist configure panel (but don&apos;t save the settings !)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CustomInstrumentTunerForm</name>
@@ -503,7 +737,31 @@ Are you sure you want to lose all your current settings ?</source>
         <translation type="obsolete">Valeur JI</translation>
     </message>
     <message>
-        <source>&lt;/h3&gt;&lt;p&gt;&lt;h3&gt;Website:&lt;/h3&gt;&lt;p&gt;homepage: &lt;a href=&quot;http://home.gna.org/fmit&quot;&gt;http://home.gna.org/fmit&lt;/a&gt;&lt;p&gt;development site: &lt;a href=&quot;http://gna.org/projects/fmit&quot;&gt;http://gna.org/projects/fmit&lt;/a&gt;&lt;p&gt;&lt;h3&gt;Authors:&lt;/h3&gt;&lt;p&gt;Gilles Degottex &lt;gilles.degottex@net2000.ch&gt;</source>
+        <source>&lt;/h3&gt;&lt;p&gt;&lt;h3&gt;Website:&lt;/h3&gt;&lt;p&gt;homepage: &lt;a href=&quot;http://home.gna.org/fmit&quot;&gt;http://home.gna.org/fmit&lt;/a&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;development site: &lt;a href=&quot;http://gna.org/projects/fmit&quot;&gt;http://gna.org/projects/fmit&lt;/a&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;donation link: &lt;a href=&quot;http://home.gna.org/fmit/donation.html&quot;&gt;http://home.gna.org/fmit/donation.html&lt;/a&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;&lt;h3&gt;Author:&lt;/h3&gt;&lt;p&gt;Gilles Degottex [gilles.degottex@net2000.ch]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;&lt;h3&gt;Packager:&lt;/h3&gt;&lt;p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>about_box</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -511,7 +769,7 @@ Are you sure you want to lose all your current settings ?</source>
     <name>DialView</name>
     <message>
         <source>Show trace</source>
-        <translation>Afficher une trace</translation>
+        <translation type="obsolete">Afficher une trace</translation>
     </message>
     <message>
         <source>Use percentages</source>
@@ -519,54 +777,53 @@ Are you sure you want to lose all your current settings ?</source>
     </message>
     <message>
         <source>Show tolerance</source>
-        <translation>Montrer la tolérance</translation>
+        <translation type="obsolete">Montrer la tolérance</translation>
     </message>
     <message>
         <source>Use cents</source>
-        <translation>Utilise la mesure en cents</translation>
+        <translation type="obsolete">Utilise la mesure en cents</translation>
     </message>
     <message>
         <source>Scale range</source>
-        <translation>Échelle d&apos;étirement</translation>
+        <translation type="obsolete">Échelle d&apos;étirement</translation>
     </message>
     <message>
         <source>Scale range (in cents)</source>
-        <translation>Échelle d&apos;étirement (en cents)</translation>
+        <translation type="obsolete">Échelle d&apos;étirement (en cents)</translation>
     </message>
 </context>
 <context>
     <name>GLErrorHistory</name>
     <message>
         <source>Error</source>
-        <translation>Erreur</translation>
+        <translation type="obsolete">Erreur</translation>
     </message>
     <message>
         <source>Keep previous notes</source>
-        <translation>Conserver les anciennes notes</translation>
+        <translation type="obsolete">Conserver les anciennes notes</translation>
     </message>
     <message>
         <source>Use percentages</source>
         <translation type="obsolete">Utiliser des pourcents</translation>
     </message>
-    <message>
-        <source>Anglo-saxon</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>Latin</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Use cents</source>
-        <translation>Utilise la mesure en cents</translation>
+        <translation type="obsolete">Utilise la mesure en cents</translation>
     </message>
     <message>
         <source>Scale range</source>
-        <translation>Échelle d&apos;étirement</translation>
+        <translation type="obsolete">Échelle d&apos;étirement</translation>
     </message>
     <message>
         <source>Scale range (in cents)</source>
-        <translation>Échelle d&apos;étirement (en cents)</translation>
+        <translation type="obsolete">Échelle d&apos;étirement (en cents)</translation>
+    </message>
+</context>
+<context>
+    <name>GLFT</name>
+    <message>
+        <source>Auto scale</source>
+        <translation type="obsolete">Adapte la taille automatiquement</translation>
     </message>
 </context>
 <context>
@@ -592,71 +849,67 @@ Are you sure you want to lose all your current settings ?</source>
     </message>
     <message>
         <source>Number of harmonics</source>
-        <translation>Nombre d&apos;harmoniques</translation>
+        <translation type="obsolete">Nombre d&apos;harmoniques</translation>
     </message>
     <message>
         <source>Harmonics</source>
-        <translation>Harmoniques</translation>
+        <translation type="obsolete">Harmoniques</translation>
     </message>
 </context>
 <context>
     <name>GLGraph</name>
     <message>
         <source>Captured Sound</source>
-        <translation>Son</translation>
+        <translation type="obsolete">Son</translation>
     </message>
     <message>
         <source>Auto scale</source>
-        <translation>Adapte la taille automatiquement</translation>
+        <translation type="obsolete">Adapte la taille automatiquement</translation>
     </message>
     <message>
         <source>Duration</source>
-        <translation>Durée</translation>
+        <translation type="obsolete">Durée</translation>
     </message>
     <message>
         <source>Max height</source>
-        <translation>Hauteur maximale</translation>
+        <translation type="obsolete">Hauteur maximale</translation>
     </message>
     <message>
         <source>Show Wave Form</source>
-        <translation>Montrer la forme d&apos;onde</translation>
+        <translation type="obsolete">Montrer la forme d&apos;onde</translation>
     </message>
     <message>
         <source>Scale factor</source>
-        <translation>Facteur d&apos;étirement</translation>
+        <translation type="obsolete">Facteur d&apos;étirement</translation>
     </message>
 </context>
 <context>
     <name>GLSample</name>
     <message>
         <source>Wave form sample</source>
-        <translation>Echantillon</translation>
+        <translation type="obsolete">Echantillon</translation>
     </message>
     <message>
         <source>Show fading</source>
-        <translation>Afficher un estompage</translation>
+        <translation type="obsolete">Afficher un estompage</translation>
     </message>
     <message>
         <source>Number of fading</source>
-        <translation>Nombre d&apos;estompages</translation>
+        <translation type="obsolete">Nombre d&apos;estompages</translation>
     </message>
 </context>
 <context>
     <name>GLVolumeHistory</name>
     <message>
         <source>Keep previous notes</source>
-        <translation>Conserver les anciennes notes</translation>
-    </message>
-    <message>
-        <source>Volume</source>
-        <translation></translation>
+        <translation type="obsolete">Conserver les anciennes notes</translation>
     </message>
 </context>
 <context>
     <name>InstrumentTunerForm</name>
     <message>
         <source>Music Instrument Tuner</source>
-        <translation>Accordeur d&apos;instruments de musique</translation>
+        <translation type="obsolete">Accordeur d&apos;instruments de musique</translation>
     </message>
     <message>
         <source>K
@@ -682,17 +935,13 @@ r</translation>
         <source>Keep errors</source>
         <translation type="obsolete">Garder les erreurs (g)</translation>
     </message>
-    <message>
-        <source>Volume</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Note Stability</source>
         <translation>Stabilité de la note</translation>
     </message>
     <message>
         <source>Stability of the playing note</source>
-        <translation>Stabilité de la note jouée</translation>
+        <translation type="obsolete">Stabilité de la note jouée</translation>
     </message>
     <message>
         <source>Tuning Frequency</source>
@@ -807,23 +1056,23 @@ Are you sure you want to lose all your current settings ?</source>
     </message>
     <message>
         <source>Do not clear histories between notes.</source>
-        <translation>N&apos;efface pas les historiques entre les notes.</translation>
+        <translation type="obsolete">N&apos;efface pas les historiques entre les notes.</translation>
     </message>
     <message>
         <source>Green if the note is stable enough, red if not and grey if there is no sound.</source>
-        <translation>Vert si la note est assez stable, rouge sinon et gris s&apos;il n&apos;y a pas de son.</translation>
+        <translation type="obsolete">Vert si la note est assez stable, rouge sinon et gris s&apos;il n&apos;y a pas de son.</translation>
     </message>
     <message>
         <source>the A3 frequency</source>
-        <translation>la fréquence du La3</translation>
+        <translation type="obsolete">la fréquence du La3</translation>
     </message>
     <message>
         <source>The played note frequency</source>
-        <translation>La fréquence de la note jouée</translation>
+        <translation type="obsolete">La fréquence de la note jouée</translation>
     </message>
     <message>
         <source>The frequency of the current played note.</source>
-        <translation>La fréquence de la note jouée.</translation>
+        <translation type="obsolete">La fréquence de la note jouée.</translation>
     </message>
     <message>
         <source>The recognized note</source>
@@ -831,11 +1080,11 @@ Are you sure you want to lose all your current settings ?</source>
     </message>
     <message>
         <source>The frequency of the note as it should be.</source>
-        <translation>La fréquence de la note comme elle devrait être.</translation>
+        <translation type="obsolete">La fréquence de la note comme elle devrait être.</translation>
     </message>
     <message>
         <source>Capture stability</source>
-        <translation>La stabilité de la capture du son</translation>
+        <translation type="obsolete">La stabilité de la capture du son</translation>
     </message>
     <message>
         <source>Green if FMIT is capturing sound, red if something goes wrong (sound server unavailable, drivers not loaded, etc.)</source>
@@ -855,7 +1104,7 @@ Are you sure you want to lose all your current settings ?</source>
     </message>
     <message>
         <source>Green if the program is capturing sound, red if something goes wrong (sound server unavailable, drivers not loaded, etc.)</source>
-        <translation>Vert si le program est en train de capturer du son, rouge si quelque chose ne va pas (serveur son indisponible, drivers pas chargés, etc.)</translation>
+        <translation type="obsolete">Vert si le program est en train de capturer du son, rouge si quelque chose ne va pas (serveur son indisponible, drivers pas chargés, etc.)</translation>
     </message>
     <message>
         <source>Settings</source>
@@ -873,6 +1122,59 @@ Are you sure you want to lose all your current settings ?</source>
         <source> cents</source>
         <translation>cents</translation>
     </message>
+    <message>
+        <source>Red if capture system is not working&lt;br/&gt;
+Grey if capture system is ok, but there is no sound enough&lt;br/&gt;
+Orange if analysis conditions are bad (like saturation)&lt;br/&gt;
+Green if a note is beeing catured and conditions are ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Free Music Instrument Tuner</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not clear graphs between notes (for error and volume graphs only)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Volume with dB scale</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Volume with dB scale.
+Computed from in the frequency domaine, from the max bin.
+The maximum is reached when the signal energy is maximal NOT when the sound saturate in time domaine.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>the tuning frequency: A4 frequency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Offset in cents from the tuning frequency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The frequency of the current played note</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The frequency of the note as it should be</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About FMIT</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invoke the about box</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Put in pause state, stop the capture, the sound analysis and all views</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>JustIntonationView</name>
@@ -924,61 +1226,61 @@ Are you sure you want to lose all your current settings ?</source>
     <name>MicrotonalView</name>
     <message>
         <source>Unkown filename: &apos;</source>
-        <translation>Nom de fichier inconnu: &apos;</translation>
+        <translation type="obsolete">Nom de fichier inconnu: &apos;</translation>
     </message>
     <message>
         <source>Keep root to left side</source>
-        <translation>Conserver la tonique à l&apos;extrémité gauche</translation>
+        <translation type="obsolete">Conserver la tonique à l&apos;extrémité gauche</translation>
     </message>
     <message>
         <source>Load Scala file ...</source>
-        <translation>Charger un fichier Scala ...</translation>
+        <translation type="obsolete">Charger un fichier Scala ...</translation>
     </message>
     <message>
         <source>used scale</source>
-        <translation>Échelle utilisée</translation>
+        <translation type="obsolete">Échelle utilisée</translation>
     </message>
     <message>
         <source>Open scale file</source>
-        <translation>Ouvrir un fichier d&apos;échelle</translation>
+        <translation type="obsolete">Ouvrir un fichier d&apos;échelle</translation>
     </message>
     <message>
         <source>Scale name already exist</source>
-        <translation>Nom d&apos;échelle déjà existant</translation>
+        <translation type="obsolete">Nom d&apos;échelle déjà existant</translation>
     </message>
     <message>
         <source>Invalid file content !</source>
-        <translation>Contenu de fichier invalid !</translation>
+        <translation type="obsolete">Contenu de fichier invalid !</translation>
     </message>
     <message>
         <source>Root&apos;s octave</source>
-        <translation>Octave de base</translation>
+        <translation type="obsolete">Octave de base</translation>
     </message>
 </context>
 <context>
     <name>MicrotonalView::ScalePreview</name>
     <message>
         <source>&lt;b&gt;name:&lt;/b&gt; </source>
-        <translation>&lt;b&gt;nom:&lt;/b&gt;</translation>
+        <translation type="obsolete">&lt;b&gt;nom:&lt;/b&gt;</translation>
     </message>
     <message>
         <source>&lt;b&gt;number of ratio:&lt;/b&gt; </source>
-        <translation>&lt;b&gt;nombre de valeures:&lt;/b&gt;</translation>
+        <translation type="obsolete">&lt;b&gt;nombre de valeures:&lt;/b&gt;</translation>
     </message>
     <message>
         <source>Invalid Scala file: </source>
-        <translation>Fichier Scala invalid:</translation>
+        <translation type="obsolete">Fichier Scala invalid:</translation>
     </message>
 </context>
 <context>
     <name>QWidget</name>
     <message>
         <source>Show </source>
-        <translation>Afficher</translation>
+        <translation type="obsolete">Afficher</translation>
     </message>
     <message>
         <source> view</source>
-        <translation>vue</translation>
+        <translation type="obsolete">vue</translation>
     </message>
 </context>
 </TS>
